Stan Math Library: stan/math/prim/mat/prob/multi_gp_cholesky_log.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
multi_gp_cholesky_log.hpp File Reference
`#include <stan/math/prim/scal/err/check_size_match.hpp>`
`#include <stan/math/prim/scal/err/check_finite.hpp>`
`#include <stan/math/prim/scal/err/check_positive.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`
`#include <stan/math/prim/mat/fun/dot_self.hpp>`
`#include <stan/math/prim/mat/fun/log.hpp>`
`#include <stan/math/prim/mat/fun/mdivide_left_tri_low.hpp>`
`#include <stan/math/prim/mat/fun/multiply.hpp>`
`#include <stan/math/prim/mat/fun/row.hpp>`
`#include <stan/math/prim/mat/fun/sum.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<bool propto, typename T_y , typename T_covar , typename T_w >
boost::math::tools::promote_args< T_y, T_covar, T_w >::type | stan::math::multi_gp_cholesky_log (const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y, const Eigen::Matrix< T_covar, Eigen::Dynamic, Eigen::Dynamic > &L, const Eigen::Matrix< T_w, Eigen::Dynamic, 1 > &w)
| The log of a multivariate Gaussian Process for the given y, w, and a Cholesky factor L of the kernel matrix Sigma. More...
template<typename T_y , typename T_covar , typename T_w >
boost::math::tools::promote_args< T_y, T_covar, T_w >::type | stan::math::multi_gp_cholesky_log (const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y, const Eigen::Matrix< T_covar, Eigen::Dynamic, Eigen::Dynamic > &L, const Eigen::Matrix< T_w, Eigen::Dynamic, 1 > &w)

[ Stan Home Page ] © 2011–2016, Stan Development Team.